Passhole
========

Passhole is a simple CLI and dmenu interface for KeePass 1.x (v3) and 2.x (v4) files.

Passhole allows you to edit and generate passwords much in the same way as the popular `pass`_ utility.

.. _pass: https://www.passwordstore.org

Passhole can also generate `correct horse battery staple`_ style passwords, which have plenty of entropy (when using 5 or more words) and are easier to type out manually than random alphanumeric passwords.

.. _correct horse battery staple: http://xkcd.com/936

Dependencies
------------

- PyUserInput
- pykeepass
    
.. code:: bash

   pip install PyUserInput pykeepass
